import * as React from 'react';
import { IHomeDetailsListProps } from './IHomeDetailsListProps';
import { Announced } from 'office-ui-fabric-react/lib/Announced';
import { TextField, ITextFieldStyles } from 'office-ui-fabric-react/lib/TextField';
import { DetailsList, DetailsListLayoutMode, Selection, IColumn } from 'office-ui-fabric-react/lib/DetailsList';
import { MarqueeSelection } from 'office-ui-fabric-react/lib/MarqueeSelection';
import { Fabric } from 'office-ui-fabric-react/lib/Fabric';
import { mergeStyles } from 'office-ui-fabric-react/lib/Styling';
import { DefaultButton, PrimaryButton } from '@microsoft/office-ui-fabric-react-bundle';
import { Panel, PanelType } from 'office-ui-fabric-react';
import './HomeDetailsList.scss';


const exampleChildClass = mergeStyles({
  display: 'block',
  marginBottom: '10px',
});

const textFieldStyles: Partial<ITextFieldStyles> = { root: { maxWidth: '300px' } };

export interface IDetailsListBasicExampleItem {
  DataCreacion: string;
  NumPregunt: string;
  tema: string;
  prodcedencia: string;
  dataRegister: string;
  dataDerivacio: string
  dataEnviament: string;
  grup: string;
  encarregatReposta: string;

}

export interface IDetailsListBasicExampleState {
  items: IDetailsListBasicExampleItem[];
  selectionDetails: string;
  itemsAux: IDetailsListBasicExampleItem[];
  showPanel: boolean;
 
}

export default class HomeDetailsList extends React.Component<IHomeDetailsListProps, IDetailsListBasicExampleState> {
  private _selection: Selection;
  private _allItems: IDetailsListBasicExampleItem[];
  private _columns: IColumn[];
  


  constructor(props: IHomeDetailsListProps) {
    super(props);
    

   
    this.handleSubmit = this.handleSubmit.bind(this);

    this.state = {
      items:[
        {
          DataCreacion:"22/01/2018  15:30:62",       // value={this.state.date ? this.state.date : ''} 
          NumPregunt: "M1219-7864",
          tema: "Motivo otorgacioón As varxe ecomon solidaria Cs (Oscar Ruiz Fuste)",
          prodcedencia: "prueba de concepto",
          dataRegister: "prueba de concepto",
          dataDerivacio: "prueba de concepto",
          dataEnviament: "prueba de concepto",
          grup:"grupo",
          encarregatReposta:"encargado"

        },
        {
          DataCreacion: "22/01/2018  15:30:62",
          NumPregunt: "M1519-8760",
          tema: "Pregunta donacs inmob Jcs PPC (Oscar Ruiz Fuste)",
          prodcedencia: "prueba de concepto",
          dataRegister: "prueba de concepto",
          dataDerivacio: "prueba de concepto",
          dataEnviament: "prueba de concepto",
          grup:"grupo",
          encarregatReposta:"encargado"
        },
        {
          DataCreacion: "22/01/2018  15:30:62",
          NumPregunt: "M1519-9124",
          tema: "Accés sona lastant MWC (Oscar Ruiz Fuste)",
          prodcedencia: "prueba de concepto",
          dataRegister: "prueba de concepto",
          dataDerivacio: "prueba de concepto",
          dataEnviament: "prueba de concepto",
          grup:"grupo",
          encarregatReposta:"encargado"
        },
        {
          DataCreacion: "22/01/2018  15:30:62",
          NumPregunt: "M1519-9500",
          tema: "Otra prueba para probar",
          prodcedencia: "prueba de concepto",
          dataRegister: "prueba de concepto",
          dataDerivacio: "prueba de concepto",
          dataEnviament: "prueba de concepto",
          grup:"grupo",
          encarregatReposta:"encargado"
        }
  
      ],
      selectionDetails: '',
      itemsAux: [],
      showPanel: false,
      
    };
      
    this._selection = new Selection({
      onSelectionChanged: () => this.setState({ selectionDetails: this._getSelectionDetails() }),
    });    

    this._columns = [
      { key: 'column1', name: 'DataCreacion', fieldName: 'DataCreacion', isMultiline: true, minWidth: 100, maxWidth: 200, isResizable: true },
      { key: 'column2', name: 'Num.Pregunt', fieldName: 'NumPregunt', isMultiline: true, minWidth: 100, maxWidth: 200, isResizable: true },
      { key: 'column3', name: 'Tema', fieldName: 'tema', minWidth: 100, isMultiline: true, maxWidth: 200, isResizable: true },
      { key: 'column4', name: 'Prodcedencia', fieldName: 'prodcedencia', isMultiline: true, minWidth: 100, maxWidth: 200, isResizable: true },
      { key: 'column5', name: 'DataRegister', fieldName: 'dataRegister', isMultiline: true, minWidth: 100, maxWidth: 200, isResizable: true },
      { key: 'column6', name: 'DataEnviament', fieldName: 'dataEnviament', isMultiline: true, minWidth: 100, maxWidth: 200, isResizable: true },
      { key: 'column7', name: 'Grup', fieldName: 'grup', minWidth: 50, isMultiline: true, maxWidth: 200, isResizable: true },
      { key: 'column8', name: 'Encarregat Reposta', fieldName: 'encarregatReposta', isMultiline: true, minWidth: 130, maxWidth: 200, isResizable: true },
      
     
      
    ];

  }

  componentDidMount() {
      this.setState({ itemsAux: this.state.items });
  }

  public render(): React.ReactElement<IHomeDetailsListProps> {
    const { items, itemsAux, selectionDetails } = this.state;


    return (
      <div  className="deatails">

      
      <Fabric>
       <div className={exampleChildClass}>{selectionDetails}</div>
        <Announced message={selectionDetails} />
        <TextField
          className={exampleChildClass}
        
          label="Filter by topic in lower case:"
          onChange={this._onFilter}
          styles={textFieldStyles}
        />
        <Announced message={`Number of items after filter applied: ${items.length}.`} />
        <MarqueeSelection selection={this._selection}>
         
          <DetailsList
            items={itemsAux}
            columns={this._columns}
            setKey="set"
            layoutMode={DetailsListLayoutMode.justified}
            selection={this._selection}
            selectionPreservedOnEmptyClick={true}
            ariaLabelForSelectionColumn="Toggle selection"
            ariaLabelForSelectAllCheckbox="Toggle selection for all items"
            checkButtonAriaLabel="Row checkbox"
            onItemInvoked={this._onItemInvoked}
          />
        
          
          <br />
          
          <div>
          <PrimaryButton
          secondaryText='Opens the Sample Panel'
          onClick={ this._onShowPanel }
          text='Añadir productos'
        />
        <Panel
          isOpen={ this.state.showPanel }
          type={ PanelType.medium }
          onDismiss={ this._onClosePanel }
          isFooterAtBottom={ true }
          headerText='Panel with footer at bottom'
          closeButtonAriaLabel='Close'
         
        >
          <form onSubmit={this.handleSubmit} >
            <div id="contenedor">
            <TextField
                label='Asunto:'
                onChange={this.handleChange} 
              />
              <TextField
                label='Categoria:'
              />
              <TextField
                label='Nº pregunta:'
              />
              <TextField
                label='Data registre:'
              />
              <TextField
                label='Grup:'
              />
              <TextField
                label='Tipus:'
              />
              <TextField
                label='Resultat del vot:'
              />
              <TextField
                label='Nº pregunta:'
              />
              <TextField
                label='Data registre:'
              />    
              <TextField
                label='Tipus:'
              />
              <TextField
                label='Resultat del vot:'
              />
              <TextField
                label='Seguiment:'
              />
              <TextField
                label='Data Comissió:'
              />
              <TextField
                label='Data entrada:'
              />
              <TextField
                label='Encarregat resposta:'
              />
              <TextField
                label='Arees Responsables:'
              />
              <TextField
                label='Estat Tramitació:'
              />
              <TextField
                label='Adjunt Resposta:'
              />
              <TextField
                label='Documents Adjunt Reposta:'
              />
              <TextField
                label='Arxiu acord final:'
              />
              
            </div>
            <br/>
            <TextField
                label='Observacions:'
                multiline
                rows={ 4 }
              />
              <br />
              <br />
              <br />


              <button
          style={ { 'marginRight': '8px' } }
        >
          Save
        </button>
        <DefaultButton
          onClick={ this._onClosePanel }
        >
          Cancel
        </DefaultButton>

              
          </form>

        </Panel>
          </div>
        </MarqueeSelection>
      </Fabric>
      </div>
    );
  }
  

  handleSubmit(event) {
    event.preventDefault();
    console.log(event.target[0].value);
  }

  handleChange(e: React.ChangeEvent<HTMLInputElement>) {
    // No longer need to cast to any - hooray for react!
    this.setState({items:[{
      DataCreacion:  e.target.value,       // value={this.state.date ? this.state.date : ''} 
          NumPregunt: "M1219-7864",
          tema: "Motivo otorgacioón As varxe ecomon solidaria Cs (Oscar Ruiz Fuste)",
          prodcedencia: "prueba de concepto",
          dataRegister: "prueba de concepto",
          dataDerivacio: "prueba de concepto",
          dataEnviament: "prueba de concepto",
          grup:"grupo",
          encarregatReposta:"encargado"


    }] });
  }

  private _onShowPanel = () => {
    this.setState({ showPanel: true });
  }
  private _onClosePanel = () => {
    this.setState({ showPanel: false });
  }

  private _getSelectionDetails(): string {
    const selectionCount = this._selection.getSelectedCount();

    switch (selectionCount) {
      case 0:
        return 'No items selected';
      case 1:
        return '1 item selected: ' + (this._selection.getSelection()[0] as IDetailsListBasicExampleItem).tema;
      default:
        return `${selectionCount} items selected`;
    }
  }

  private _onFilter = (ev: React.FormEvent<HTMLInputElement | HTMLTextAreaElement>, text: string): void => {

    this.setState({
      
      itemsAux: text ? this.state.items.filter(i => i.tema.toLowerCase().indexOf(text)  > -1) : this.state.items,

     
    });
    //alert(`que es lo que aparece: ${text} ${this.state.items.length}`);
  }

  private _onItemInvoked = (item: IDetailsListBasicExampleItem): void => {
    alert(`Item invoked: ${item.tema}`);
  }
}
